==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/rep_base/languages/en/tl_repository.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');
/**
 * TYPOlight Repository :: Language file for frontend module (en)
 *
 * NOTE: this file was edited with tabs set to 4.
 * @package Repository
 * @copyright Copyright (C) 2008 by Peter Koch, IBK Software AG
 * @license See accompaning file LICENSE.txt
 */
 
/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['category']      = array('Category', 'Please select the extension category.');
$GLOBALS['TL_LANG']['tl_repository']['copyright']     = array('Copyright', 'Here you can enter a copyright notice (e.g. &amp;copy; 2007,2008 Jerry Miller Webservices Inc).');
$GLOBALS['TL_LANG']['tl_repository']['demo']          = array('Demo available', 'The commercial extension can be installed as demo without a key.');
$GLOBALS['TL_LANG']['tl_repository']['description']   = array('Description', 'These HTML tags are allowed: %s');
$GLOBALS['TL_LANG']['tl_repository']['extension']     = array('Extension', 'Please select the extension name.');
$GLOBALS['TL_LANG']['tl_repository']['functionality'] = array('Functionality', 'Does the extension provide the expected functionality?');
$GLOBALS['TL_LANG']['tl_repository']['license']       = array('License', 'Please enter a short license information. You may add full license information in a file LICENSE.txt.');
$GLOBALS['TL_LANG']['tl_repository']['name']          = array('Name', 'Extension names must start with a-z, A-Z or 0-9, whereby lowercase names are prefered. Additionally, the characters _ and - are allowed within the name.');
$GLOBALS['TL_LANG']['tl_repository']['popularity']    = array('Popularity', '%s/%s (downloads/installs)');
$GLOBALS['TL_LANG']['tl_repository']['quality']       = array('Quality', 'How robust is the extension and how painless is installation and maintenance?');
$GLOBALS['TL_LANG']['tl_repository']['releasedate']   = array('Release date', 'Enter the publishing date of this release as YYYY-MM-DD.');
$GLOBALS['TL_LANG']['tl_repository']['selversion']    = array('Version', 'Please select the version');
$GLOBALS['TL_LANG']['tl_repository']['type']          = array('Type', 'Please select the extension type.');
$GLOBALS['TL_LANG']['tl_repository']['usability']     = array('Usability', 'Does the extension meet the TYPOlight standards for usability and accessability?');
$GLOBALS['TL_LANG']['tl_repository']['version']       = array('Version', 'Version numbers must be in format n.n.n s, where n are integers and s is one of: alpha1, alpha2, alpha3, beta1, beta2, beta3, rc1, rc2, rc3, stable');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['author']            = 'Author';
$GLOBALS['TL_LANG']['tl_repository']['build']             = 'Build';
$GLOBALS['TL_LANG']['tl_repository']['cancel']            = 'Cancel';
$GLOBALS['TL_LANG']['tl_repository']['continue']          = 'Continue';
$GLOBALS['TL_LANG']['tl_repository']['dependencies']      = 'Dependencies of this extension';
$GLOBALS['TL_LANG']['tl_repository']['dependents']        = 'Other extensions depending on this one';
$GLOBALS['TL_LANG']['tl_repository']['dependentsdel']     = 'The following extensions are dependent from <em>%s</em> and may render broken:';
$GLOBALS['TL_LANG']['tl_repository']['donate']            = 'Donate';
$GLOBALS['TL_LANG']['tl_repository']['downloads']         = 'Package downloads';
$GLOBALS['TL_LANG']['tl_repository']['extensionnotfound'] = 'Extension not found.';
$GLOBALS['TL_LANG']['tl_repository']['forum']             = 'Forum';
$GLOBALS['TL_LANG']['tl_repository']['installs']          = 'Online installs';
$GLOBALS['TL_LANG']['tl_repository']['langtrans']         = '%s transl.';
$GLOBALS['TL_LANG']['tl_repository']['manual']            = 'Manual';
$GLOBALS['TL_LANG']['tl_repository']['no']                = 'no';
$GLOBALS['TL_LANG']['tl_repository']['noextensionsfound'] = 'No extensions found.';
$GLOBALS['TL_LANG']['tl_repository']['orderby']           = 'Order by';
$GLOBALS['TL_LANG']['tl_repository']['otherlanguages']    = 'Other languages';
$GLOBALS['TL_LANG']['tl_repository']['pageof']            = 'Page %s of %s';
$GLOBALS['TL_LANG']['tl_repository']['ratingfmt']         = '%.2f (%d votes)';
$GLOBALS['TL_LANG']['tl_repository']['reldownloads']      = 'Release downloads';
$GLOBALS['TL_LANG']['tl_repository']['releasenotesfor']   = 'Release notes and change log for %s';
$GLOBALS['TL_LANG']['tl_repository']['relfunctionality']  = 'Release functionality';
$GLOBALS['TL_LANG']['tl_repository']['relinstalls']       = 'Release installs';
$GLOBALS['TL_LANG']['tl_repository']['relquality']        = 'Release quality';
$GLOBALS['TL_LANG']['tl_repository']['relrating']         = 'Release rating';
$GLOBALS['TL_LANG']['tl_repository']['relupdates']        = 'Release updates';
$GLOBALS['TL_LANG']['tl_repository']['relusability']      = 'Release usability';
$GLOBALS['TL_LANG']['tl_repository']['save']              = 'Save';
$GLOBALS['TL_LANG']['tl_repository']['shop']              = 'Shop';
$GLOBALS['TL_LANG']['tl_repository']['showpicture']       = 'Show full size picture';
$GLOBALS['TL_LANG']['tl_repository']['state']             = 'State';
$GLOBALS['TL_LANG']['tl_repository']['tag']               = 'Tag';
$GLOBALS['TL_LANG']['tl_repository']['thumbnail']         = 'Thumb nail picture';
$GLOBALS['TL_LANG']['tl_repository']['totdownloads']      = 'Total downloads';
$GLOBALS['TL_LANG']['tl_repository']['totfunctionality']  = 'Total functionality';
$GLOBALS['TL_LANG']['tl_repository']['totinstalls']       = 'Total installs';
$GLOBALS['TL_LANG']['tl_repository']['totquality']        = 'Total quality';
$GLOBALS['TL_LANG']['tl_repository']['totrating']         = 'Total rating';
$GLOBALS['TL_LANG']['tl_repository']['totupdates']        = 'Total updates';
$GLOBALS['TL_LANG']['tl_repository']['totusability']      = 'Total usability';
$GLOBALS['TL_LANG']['tl_repository']['versionfrom']       = 'Version from';
$GLOBALS['TL_LANG']['tl_repository']['versions']          = 'Other versions';
$GLOBALS['TL_LANG']['tl_repository']['versionto']         = 'Version to';
$GLOBALS['TL_LANG']['tl_repository']['yes']               = 'yes';

/**
 * Types
 */
$GLOBALS['TL_LANG']['tl_repository']['type_options']['free']       = 'Free';
$GLOBALS['TL_LANG']['tl_repository']['type_options']['private']    = 'Private';
$GLOBALS['TL_LANG']['tl_repository']['type_options']['commercial'] = 'Commercial';

/**
 * Categories
 */
$GLOBALS['TL_LANG']['tl_repository']['category_options']['application'] = 'Application';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['utility']     = 'Utility';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['template']    = 'Template';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['widget']      = 'Widget';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['plugin']      = 'Plugin';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['other']       = 'Other';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['core']        = 'Core';

/**
 * Sorting
 */
$GLOBALS['TL_LANG']['tl_repository']['order_options']['reldate'] = 'Releasedate';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['rating']  = 'Rating';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['popular'] = 'Popularity';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['name']    = 'Name';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['title']   = 'Title';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['author']  = 'Author';

/**
 * States
 */
$GLOBALS['TL_LANG']['tl_repository']['state_options']['alpha']  = 'Alpha';
$GLOBALS['TL_LANG']['tl_repository']['state_options']['beta']   = 'Beta';
$GLOBALS['TL_LANG']['tl_repository']['state_options']['rc']     = 'RC';
$GLOBALS['TL_LANG']['tl_repository']['state_options']['stable'] = 'Stable';

?>

==> typolight-2.6.7.tar.gz: typolight-2.6.7/system/modules/rep_base/languages/en/tl_repository.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');
/**
 * TYPOlight Repository :: Language file for frontend module (en)
 *
 * NOTE: this file was edited with tabs set to 4.
 * @package Repository
 * @copyright Copyright (C) 2008 by Peter Koch, IBK Software AG
 * @license See accompaning file LICENSE.txt
 */
 
/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['category']      = array('Category', 'Please select the extension category.');
$GLOBALS['TL_LANG']['tl_repository']['copyright']     = array('Copyright', 'Here you can enter a copyright notice (e.g. &amp;copy; 2007,2008 Jerry Miller Webservices Inc).');
$GLOBALS['TL_LANG']['tl_repository']['demo']          = array('Demo available', 'The commercial extension can be installed as demo without a key.');
$GLOBALS['TL_LANG']['tl_repository']['description']   = array('Description', 'These HTML tags are allowed: %s');
$GLOBALS['TL_LANG']['tl_repository']['extension']     = array('Extension', 'Please select the extension name.');
$GLOBALS['TL_LANG']['tl_repository']['functionality'] = array('Functionality', 'Does the extension provide the expected functionality?');
$GLOBALS['TL_LANG']['tl_repository']['license']       = array('License', 'Please enter a short license information. You may add full license information in a file LICENSE.txt.');
$GLOBALS['TL_LANG']['tl_repository']['name']          = array('Name', 'Extension names must start with a-z, A-Z or 0-9, whereby lowercase names are prefered. Additionally, the characters _ and - are allowed within the name.');
$GLOBALS['TL_LANG']['tl_repository']['popularity']    = array('Popularity', '%s/%s (downloads/installs)');
$GLOBALS['TL_LANG']['tl_repository']['quality']       = array('Quality', 'How robust is the extension and how painless is installation and maintenance?');
$GLOBALS['TL_LANG']['tl_repository']['releasedate']   = array('Release date', 'Enter the publishing date of this release as YYYY-MM-DD.');
$GLOBALS['TL_LANG']['tl_repository']['selversion']    = array('Version', 'Please select the version');
$GLOBALS['TL_LANG']['tl_repository']['type']          = array('Type', 'Please select the extension type.');
$GLOBALS['TL_LANG']['tl_repository']['usability']     = array('Usability', 'Does the extension meet the TYPOlight standards for usability and accessability?');
$GLOBALS['TL_LANG']['tl_repository']['version']       = array('Version', 'Version numbers must be in format n.n.n s, where n are integers and s is one of: alpha1, alpha2, alpha3, beta1, beta2, beta3, rc1, rc2, rc3, stable');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['author']            = 'Author';
$GLOBALS['TL_LANG']['tl_repository']['build']             = 'Build';
$GLOBALS['TL_LANG']['tl_repository']['cancel']            = 'Cancel';
$GLOBALS['TL_LANG']['tl_repository']['continue']          = 'Continue';
$GLOBALS['TL_LANG']['tl_repository']['dependencies']      = 'Dependencies of this extension';
$GLOBALS['TL_LANG']['tl_repository']['dependents']        = 'Other extensions depending on this one';
$GLOBALS['TL_LANG']['tl_repository']['dependentsdel']     = 'The following extensions are dependent from <em>%s</em> and may render broken:';
$GLOBALS['TL_LANG']['tl_repository']['donate']            = 'Donate';
$GLOBALS['TL_LANG']['tl_repository']['downloads']         = 'Package downloads';
$GLOBALS['TL_LANG']['tl_repository']['extensionnotfound'] = 'Extension not found.';
$GLOBALS['TL_LANG']['tl_repository']['forum']             = 'Forum';
$GLOBALS['TL_LANG']['tl_repository']['installs']          = 'Online installs';
$GLOBALS['TL_LANG']['tl_repository']['langtrans']         = '%s transl.';
$GLOBALS['TL_LANG']['tl_repository']['manual']            = 'Manual';
$GLOBALS['TL_LANG']['tl_repository']['no']                = 'no';
$GLOBALS['TL_LANG']['tl_repository']['noextensionsfound'] = 'No extensions found.';
$GLOBALS['TL_LANG']['tl_repository']['orderby']           = 'Order by';
$GLOBALS['TL_LANG']['tl_repository']['otherlanguages']    = 'Other languages';
$GLOBALS['TL_LANG']['tl_repository']['pageof']            = 'Page %s of %s';
$GLOBALS['TL_LANG']['tl_repository']['ratingfmt']         = '%.2f (%d votes)';
$GLOBALS['TL_LANG']['tl_repository']['reldownloads']      = 'Release downloads';
$GLOBALS['TL_LANG']['tl_repository']['releasenotesfor']   = 'Release notes and change log for %s';
$GLOBALS['TL_LANG']['tl_repository']['relfunctionality']  = 'Release functionality';
$GLOBALS['TL_LANG']['tl_repository']['relinstalls']       = 'Release installs';
$GLOBALS['TL_LANG']['tl_repository']['relquality']        = 'Release quality';
$GLOBALS['TL_LANG']['tl_repository']['relrating']         = 'Release rating';
$GLOBALS['TL_LANG']['tl_repository']['relupdates']        = 'Release updates';
$GLOBALS['TL_LANG']['tl_repository']['relusability']      = 'Release usability';
$GLOBALS['TL_LANG']['tl_repository']['save']              = 'Save';
$GLOBALS['TL_LANG']['tl_repository']['shop']              = 'Shop';
$GLOBALS['TL_LANG']['tl_repository']['showpicture']       = 'Show full size picture';
$GLOBALS['TL_LANG']['tl_repository']['state']             = 'State';
$GLOBALS['TL_LANG']['tl_repository']['tag']               = 'Tag';
$GLOBALS['TL_LANG']['tl_repository']['thumbnail']         = 'Thumb nail picture';
$GLOBALS['TL_LANG']['tl_repository']['totdownloads']      = 'Total downloads';
$GLOBALS['TL_LANG']['tl_repository']['totfunctionality']  = 'Total functionality';
$GLOBALS['TL_LANG']['tl_repository']['totinstalls']       = 'Total installs';
$GLOBALS['TL_LANG']['tl_repository']['totquality']        = 'Total quality';
$GLOBALS['TL_LANG']['tl_repository']['totrating']         = 'Total rating';
$GLOBALS['TL_LANG']['tl_repository']['totupdates']        = 'Total updates';
$GLOBALS['TL_LANG']['tl_repository']['totusability']      = 'Total usability';
$GLOBALS['TL_LANG']['tl_repository']['versionfrom']       = 'Version from';
$GLOBALS['TL_LANG']['tl_repository']['versions']          = 'Other versions';
$GLOBALS['TL_LANG']['tl_repository']['versionto']         = 'Version to';
$GLOBALS['TL_LANG']['tl_repository']['yes']               = 'yes';

/**
 * Types
 */
$GLOBALS['TL_LANG']['tl_repository_type_options']['free']       = 'Free';
$GLOBALS['TL_LANG']['tl_repository_type_options']['private']    = 'Private';
$GLOBALS['TL_LANG']['tl_repository_type_options']['commercial'] = 'Commercial';

/**
 * Categories
 */
$GLOBALS['TL_LANG']['tl_repository_category_options']['application'] = 'Application';
$GLOBALS['TL_LANG']['tl_repository_category_options']['utility']     = 'Utility';
$GLOBALS['TL_LANG']['tl_repository_category_options']['template']    = 'Template';
$GLOBALS['TL_LANG']['tl_repository_category_options']['widget']      = 'Widget';
$GLOBALS['TL_LANG']['tl_repository_category_options']['plugin']      = 'Plugin';
$GLOBALS['TL_LANG']['tl_repository_category_options']['other']       = 'Other';
$GLOBALS['TL_LANG']['tl_repository_category_options']['core']        = 'Core';

/**
 * Sorting
 */
$GLOBALS['TL_LANG']['tl_repository_order_options']['reldate'] = 'Releasedate';
$GLOBALS['TL_LANG']['tl_repository_order_options']['rating']  = 'Rating';
$GLOBALS['TL_LANG']['tl_repository_order_options']['popular'] = 'Popularity';
$GLOBALS['TL_LANG']['tl_repository_order_options']['name']    = 'Name';
$GLOBALS['TL_LANG']['tl_repository_order_options']['title']   = 'Title';
$GLOBALS['TL_LANG']['tl_repository_order_options']['author']  = 'Author';

/**
 * States
 */
$GLOBALS['TL_LANG']['tl_repository_state_options']['alpha']  = 'Alpha';
$GLOBALS['TL_LANG']['tl_repository_state_options']['beta']   = 'Beta';
$GLOBALS['TL_LANG']['tl_repository_state_options']['rc']     = 'RC';
$GLOBALS['TL_LANG']['tl_repository_state_options']['stable'] = 'Stable';

?>
